<template>
  <gree-popup class="temun-picker" v-model="isShowPicker" position="bottom" get-container="body" safe-area-inset-bottom @hide="onHide">
    <gree-picker
      ref="picker"
      :cancel-button-text="$language('popup.cancel')"
      :confirm-button-text="$language('popup.confirm')"
      :title="$language('TemUn.title')"
      :columns="silderList"
      :default-index="currentIndex"
      @cancel="onCancel"
      @confirm="confirmHandler"
    />
  </gree-popup>
</template>

<script>
import { Picker, Popup } from 'gree-ui';
import { types } from '@/store/types';
import temUnChange from '@/mixins/tem';
import { mapState, mapMutations, mapGetters, mapActions } from 'vuex';

export default {
  name: 'TemUnPicker',
  components: {
    [Picker.name]: Picker,
    [Popup.name]: Popup
  },
  mixins: [temUnChange],
  data() {
    return {
      isShowPicker: false,
      currentVal: 26,
      jsonMapC: {
        1: 'CoolSvStTemMin',
        2: 'HumiSvStTemMin',
        4: 'HeatSvStTemMax',
        6: 'Heat3DSvStTemMax',
        7: 'Heat2SvStTemMax'
      },
      jsonMapF: {
        1: 'CoolSvStTemMinD',
        2: 'HumiSvStTemMinD',
        4: 'HeatSvStTemMaxD',
        6: 'Heat3DSvStTemMaxD',
        7: 'Heat2SvStTemMaxD'
      }
    };
  },
  computed: {
    ...mapState('control', {
      TemUnPopup: state => state.popup.TemUnPopup,
      TemUn: state => state.dataObject.TemUn,
      SetTem: state => state.dataObject.SetTem,
      Add01: state => state.dataObject['Add0.1'] || 0,
      TemRec: state => state.dataObject.TemRec,
      HumiEnable: state => state.dataObject.HumiEnable,
      Mod: state => state.dataObject.Mod,
      CoolSvStTemMin: state => state.dataObject.CoolSvStTemMin || 18,
      HumiSvStTemMin: state => state.dataObject.HumiSvStTemMin || 18,
      HeatSvStTemMax: state => state.dataObject.HeatSvStTemMax || 18,
      Heat2SvStTemMax: state => state.dataObject.Heat2SvStTemMax || 18,
      CoolSvStTemMinD: state => state.dataObject.CoolSvStTemMinD || 20,
      HumiSvStTemMinD: state => state.dataObject.HumiSvStTemMinD || 18,
      HeatSvStTemMaxD: state => state.dataObject.HeatSvStTemMaxD || 18,
      Heat3DSvStTemMax: state => state.dataObject.Heat3DSvStTemMax || 18,
      Heat2SvStTemMaxD: state => state.dataObject.Heat2SvStTemMaxD || 18,
      Heat3DSvStTemMaxD: state => state.dataObject.Heat3DSvStTemMaxD || 18
    }),
    ...mapGetters([
      'modTextKey',
      'modIdentifier',
      'modCurrentStatusName',
      'temSetVal',
      'temSetJson',
      'temMinVal',
      'temStep',
      'temMaxVal',
      'spModCurrentStatusName',
      'spModIdentifier'
    ]),
    ...mapGetters('machine', ['statusMap']),

    // 滑轮配置
    silderList() {
      const result = [
        { text: '℃', value: 0 },
        { text: '℉', value: 1 }
      ];
      return result;
    },
    // 当前设置温度单位
    currentIndex() {
      const value = this.TemUn;
      return value;
    }
  },
  mounted() {
    window.$bus.$on('updataVal', value => {
      this.currentVal = value;
    });
  },
  watch: {
    TemUnPopup(val) {
      this.isShowPicker = val;
    }
  },
  methods: {
    ...mapMutations('control', {
      SetPopup: 'SET_POPUP',
      setDataObject: 'SET_DATA_OBJECT'
    }),
    ...mapActions({
      stateMatchineInterFace: 'STATE_MACHINE_INTERFACE',
      sendData: types.SEND_DATA,
      sendCtrl: types.SEND_CTRL
    }),
    onHide() {
      this.$refs.picker.setColumnIndex(0, this.TemUn);
      this.SetPopup({ TemUnPopup: false });
    },
    onCancel() {
      this.SetPopup({ TemUnPopup: false });
    },
    confirmHandler() {
      this.SetPopup({ TemUnPopup: false });
      try {
        const { value } = this.$refs.picker.getValues()[0];
        if (value === this.TemUn) return;
        this.stateMatchineInterFace({
          data: {
            TemUn: value
            // TemRec: this.TemRec
          }
        });
        if (this.Mod !== 2 || (this.Mod === 2 && !this.HumiEnable)) {
          if (value) {
            window.$bus.$on('updataVal', value => {
              this.currentVal = value;
            });
            console.log(
              '切华氏',
              this.temSetVal,
              this.tempC2F(this.temSetVal, this.TemRec),
              this.tempF2C(this.tempC2F(this.temSetVal, this.TemRec))[3],
              this[this.jsonMapC[this.Mod]]
            );
            this.sendData({
              'Add0.1': this.Add01,
              TemRec: this.tempF2C(this.tempC2F(this.temSetVal))[3]
            });
            this.sendCtrl({
              SetTem: this.tempF2C(this.tempC2F(this.temSetVal, this.TemRec))[1]
            });
            this.setDataObject({
              SetTem: this.SetTem,
              [this.jsonMapF[this.Mod]]: Math.round(this[this.jsonMapC[this.Mod]] * 1.8 + 32)
            });
          } else {
            console.log('切摄氏--------------------------', this.SetTem, this.temStep, this.temSetVal, this.currentVal, this.tempF2C(this.currentVal));
            this.sendData({
              SetTem: this.temStep === 1 ? this.tempF2C(this.currentVal)[1] : this.tempF2C(this.currentVal)[2],
              TemRec: this.tempF2C(this.currentVal)[3]
            });
            this.setDataObject({
              [this.jsonMapC[this.Mod]]: Math.round((this[this.jsonMapF[this.Mod]] - 32) / 1.8)
            });
          }
        }
        // this.setDataObject({ SetTem: 17 });
      } catch (e) {
        console.log(e);
      }
    }
  }
};
</script>

<style lang="scss"></style>
